@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 
+from pyrql.exceptions import RQLError
+from pyrql.exceptions import RQLQueryError
 from pyrql.exceptions import RQLSyntaxError
 from pyrql.parser import Parser
-from pyrql.unparser import Unparser
 from pyrql.query import Query
-
+from pyrql.unparser import Unparser
 
 __title__ = "pyrql"
-__version__ = "0.6.1"
+__version__ = "0.7.0"
 __author__ = "Pedro Werneck"
 __license__ = "MIT"
 
@@ -16,4 +17,4 @@ parse = Parser().parse
 
 unparse = Unparser().unparse
 
-__all__ = ["parse", "unparse", "Query", "RQLSyntaxError"]
+__all__ = ["parse", "unparse", "Query", "RQLError", "RQLQueryError", "RQLSyntaxError"]
